package com.staffing.custom.mapper;

import java.util.List;
import com.staffing.custom.domain.StEmployee;
import org.apache.ibatis.annotations.Param;

/**
 * 员工Mapper接口
 * 
 * @author staffing
 * @date 2024-08-27
 */
public interface StEmployeeMapper 
{
    /**
     * 查询员工
     * 
     * @param id 员工主键
     * @return 员工
     */
    public StEmployee selectStEmployeeById(Long id);

    public StEmployee selectStEmployeeByPhone(@Param("phone") String phone);


    public List<StEmployee> selectStEmployeeByIds(@Param("uids")List<Long> ids);
    /**
     * 查询员工列表
     * 
     * @param stEmployee 员工
     * @return 员工集合
     */
    public List<StEmployee> selectStEmployeeList(StEmployee stEmployee);

    /**
     * 新增员工
     * 
     * @param stEmployee 员工
     * @return 结果
     */
    public int insertStEmployee(StEmployee stEmployee);

    /**
     * 修改员工
     * 
     * @param stEmployee 员工
     * @return 结果
     */
    public int updateStEmployee(StEmployee stEmployee);

    public int updateStEmployeeOrNull(StEmployee stEmployee);


    /**
     * 删除员工
     * 
     * @param id 员工主键
     * @return 结果
     */
    public int deleteStEmployeeById(Long id);

    /**
     * 批量删除员工
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStEmployeeByIds(Long[] ids);
}
